<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:java="http://xml.apache.org/xslt/java"
	xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
	xmlns:gslib="http://www.greenstone.org/skinning"
	xmlns:gsf="http://www.greenstone.org/formatting"
	extension-element-prefixes="java util"
	exclude-result-prefixes="java util">

  <!-- optional cgi-params for links to document pages -->
  <!-- needed here because collectionConfig.xml defined a template in
       its *global* section that uses gsf:link, which in turn then
       generates XSL tags that refer to opt-doc-link-arg -->
  <xsl:variable name="opt-doc-link-args"></xsl:variable>

  <xsl:template name="create-banner">		
    <!-- complete supress banner on the about page -->
    <!--
    <div id="gs_banner" class="ui-widget-header ui-corner-bottom">
      <div id="titlesearchcontainer">
	<xsl:call-template name="page-title-area"/>
	<div style="clear:both;"><xsl:text> </xsl:text></div>
      </div>
      <xsl:call-template name="browsing-tabs"/>
    </div>
    -->
  </xsl:template>


  <xsl:template name="coll-description">
    <xsl:variable name="numDocs" select="/page/pageResponse/collection/metadataList/metadata[@name='numDocs']"/>
    
    <figure style="float: right;">
      <style> #gotohelp:hover { background-color: #662020;}</style>
      <div id="gotohelp" class="ui-button ui-widget ui-state-default ui-corner-all" style="vertical-align:top; color: white; padding: 10px;">
	<a href="{$library_name}/collection/{$collName}/page/help">Help</a>
      </div>
      <img src="https://www.heritage.org.nz/-/media/heritage/images/protect/archaeology/digital-library-page.jpg?useCustomFunctions=1&amp;mw=920" width="220" alt="Archaeological digital library" />
    </figure>

    <h1>Archaeological Reports Digital Library</h1>

    <p>
      Heritage New Zealand holds an extensive collection of
      archaeological reports resulting from site surveys, excavations,
      research programmes and archaeological authorities.  The digital
      library provides searching and browsing access to these

<!--
      <gsf:metadata type="collection" name="numDocs"/> 
-->
<!--
      <xsl:value-of select="$numDocs"/>
-->
      volumes, which date from the
      early 1970s to the present day.
    </p>
    

    <p>
      You can locate and download reports through the search interface:
    </p>
    <div id="titlesearchcontainer">
      <style>
	#quicksearcharea    { float: left;  text-align: left; }
	#quicksearcharea ul { float: right; text-align: right; }
      </style>
      <xsl:call-template name="quick-search-area"/>
      <div style="clear:both;"><xsl:text> </xsl:text></div>
    </div>

    <p>
      Or else browse by:
    </p>
    <style>
      #gs-nav li:hover  { background-color: #662020; }
      #inpage-browsing-tabs li  { float: inherit;  display: inherit; margin: 5px; }
      #inpage-browsing-tabs { width: 200px; } 

    </style>
    <div id="inpage-browsing-tabs" >
      <xsl:call-template name="browsing-tabs"/>
    </div>

    <div id="gotoFavourites" style="display: none; padding-top: 10px;">
      <a href="{$library_name}?a=g&amp;sa=berry&amp;c=&amp;s=DisplayList&amp;rt=r&amp;p.c=">
	<img src="interfaces/{$interface_name}/images/{$selected_favourite_icon}" title="view favourites" width="15" height="15" border="0" />
      </a>
      You have also have <span id="favouritesCount">0</span> item(s) marked as favourites, which you can access
      <a href="{$library_name}?a=g&amp;sa=berry&amp;c=&amp;s=DisplayList&amp;rt=r&amp;p.c=">here</a>.
    </div>
    <script>
      <xsl:text disable-output-escaping="yes">
	$(document).ready(
	  countFavourites(function(favourites_count) { 
	    if (favourites_count>0) { 
	      $('#favouritesCount').html(favourites_count);
	      $('#gotoFavourites').show();
	    } 
	  })
        );
      </xsl:text>
    </script>

    <p style="padding-top: 10px;">
      A spreadsheet of the metadata of all the reports is available 
      for download:
    </p>
    <ul style="list-style: none;">
      <li>
	<a href="sites/{$site_name}/collect/{$collName}/for-download/Archaeological-Reports-24-July-2019.csv">
	  <img src="interfaces/{$interface_name}/images/iexcel.gif" />
	  Archaeological-Reports.csv</a>
      </li>
    </ul>

    <p style="padding-top: 10px;">
      Should you prefer, you may contact us as follows:
    </p>
    <p style="padding-left: 20px">
      <i>
	Archaeological Reports Digital Library<br/>
	Heritage New Zealand Pouhere Taonga<br/>
	Antrim House<br/>
	63 Boulcott Street<br/>
	P O Box 2629<br/>
	Wellington 6160
      </i>
    </p>
    <p style="padding-left: 20px">
      <i>
	Phone: +64 4 472 4341
      </i>
    </p>
    <p style="padding-left: 20px">
      <i>
	Email: <a href="mailto:archaeologist@heritage.org.nz">archaeologist@heritage.org.nz</a>
      </i>
    </p>

    
    
  </xsl:template>

</xsl:stylesheet>  
